@@ -4,13 +4,14 @@ import json
 
 print(f"Importing {os.path.basename(__file__)}...")
 
-config_dir = os.path.dirname(os.path.abspath(__file__))
+CONFIG_DIR = os.path.dirname(os.path.abspath(__file__)) + "/../"
+CONFIG_SECRET_DIR = os.path.expanduser("~")
 
-with open(f"{config_dir}/../config/config.json", encoding="utf8") as file:
+with open(f"{CONFIG_DIR}/config/config.json", encoding="utf8") as file:
     config_file = json.load(file)
 
 # load secret keys from secret.json
-with open(f"{os.path.expanduser('~')}/.secret.json", encoding="utf8") as file:
+with open(f"{CONFIG_SECRET_DIR}/.secret.json", encoding="utf8") as file:
     secret_file = json.load(file)
 
 PRINTER_HOST = config_file["host"]
@@ -46,3 +47,5 @@ if config_file["debug_logging"].lower() == "false":
     DEBUG_LOGGING = False
 
 GOOGLE_SHEETS_SERIAL_NAME = config_file["google_sheets_serial_name"]
+
+GOOGLE_SHEETS_SERIAL_PRINT = config_file["google_sheets_serial_print"].lower() == "true"
